@@ -10,7 +10,7 @@ $client->do_one_loop while 1;
 
 =head1 NAME
 
-/tatoeba/000-basic.pl - Bare minimum example BitTorrent client
+000-basic.pl - Bare minimum example BitTorrent client
 
 =head1 Description
 
@@ -23,6 +23,8 @@ C<Net::BitTorrent>-based client.
 
 =head1 Lowdown
 
+This section only makes sense when you view the source.
+
 =over
 
 =item Line 5
@@ -69,6 +71,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: 000-basic.pl fac4ae0 2009-01-27 17:00:38Z sanko@cpan.org $
+=for svn $Id: 000-basic.pl a7a7e9d 2009-02-09 04:49:58Z sanko@cpan.org $
 
 =cut
